Documentation
¶
Index ¶
- func Config(args ...string) error
- func Debug(args ...any)
- func DebugTrace(depth int, args ...any)
- func Error(args ...any)
- func ErrorTrace(depth int, args ...any)
- func Info(args ...any)
- func InfoTrace(depth int, args ...any)
- func Log(args ...any)
- func LogTrace(depth int, args ...any)
- func Message(args ...any)
- func Shutdown()
- func Warn(args ...any)
- func WarnTrace(depth int, args ...any)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Config ¶ added in v1.2.1
Config changes the logger configuration with string statements. e.g. quick.Config("level=debug")
func Debug ¶
func Debug(args ...any)
Debug logs a debug message. Message is dropped if logger's level is higher than debug.
func Error ¶
func Error(args ...any)
Error logs an error message. Message is dropped if logger's level is higher than error.
func Info ¶
func Info(args ...any)
Info logs an info message. Message is dropped if logger's level is higher than info.
func Message ¶ added in v1.2.1
func Message(args ...any)
Message writes a log record without timestamp and log level.
func Shutdown ¶
func Shutdown()
Shutdown performs a graceful shutdown of the logger with default default timeout
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.